#--------------------------------------------------------------------------
#  FileBrowser.nib/Interpreter.tcl
#  Copyright (c) 1997, AAA+ Software (info@aaa-plus.com)
#  All rights reserved.
#  Author: W. Pitzeier
#
#  You may freely copy, distribute and reuse the code in this example.
#  AAA+ disclaims any warranty of any kind, expressed or implied,
#  as to its fitness for any particular use.
#--------------------------------------------------------------------------


# teach the two skills needed for a passive browser delegate
objc:teach $self {

    # skill that gets called each time a new cell is displayed
    - void browser: sender willDisplayCell: cell atRow: {int row} column: {int column} {
	global browser fileManager
        set path [$browser pathToColumn: $column]
	set file [[[$fileManager directoryContentsAtPath: $path] sortedArrayUsingSelector: caseInsensitiveCompare: ] objectAtIndex: $row]
	$cell setStringValue: $file
	set path [$path stringByAppendingPathComponent: $file]
	if {[$fileManager directoryContentsAtPath: $path] == "nil"} {
	    $cell setLeaf: [YES]
	} else {
	    $cell setLeaf: [NO]
	}
    }
    
    # skill that gets called each time a new column is displayed
    - int browser: sender numberOfRowsInColumn: {int column}
    {
	global browser fileManager
	[$fileManager directoryContentsAtPath: [$browser path]] count
    }
}


objc:teach $browser {

    - pathToColumn: {int column} {
        global rootPath
        set path [former pathToColumn: $column]
	if {[$path isEqualToString: [@ ""]]} {
	    return $rootPath
	} else {
	    return [$rootPath stringByAppendingPathComponent: $path]
	}
    }

    # Needed for supporting filename services (such as "Joy Snooping")
    - validRequestorForSendType: sendType returnType: returnType {
	if {[$sendType isEqualToString: [NSFilenamesPboardType]]} {
	    return $self
	}
	return nil
    }
    
    - BOOL writeSelectionToPasteboard: pboard types: types {
	$pboard declareTypes: [NSArray arrayWithObject: [NSFilenamesPboardType]] owner: nil
	$pboard setPropertyList: [NSArray arrayWithObject: [$self path]] forType: [NSFilenamesPboardType] 
    }
    
    - void action: sender {
        global icon workspace
	set fileicon [$workspace iconForFile: [$self path]]
	if {$fileicon == "nil"} {
	    $icon setEnabled: [NO]
	} else {
	    $icon setEnabled: [YES]
	}
	$icon setImage: $fileicon
    }
}


objc:teach $icon {

    - void action: sender {
        global workspace browser
	$workspace openFile: [$browser path]
    }
}

$browser setDelegate: $self
# for window resizing:
# if the window width gets to small,
# reduze the number of displayed columns
$browser setMinColumnWidth: 135
# if the window width gets larger, display more columns
$browser setMaxVisibleColumns: 5
set fileManager [NSFileManager defaultManager]
set workspace [NSWorkspace sharedWorkspace]

$NSApp registerServicesMenuSendTypes: [NSArray arrayWithObject: [NSFilenamesPboardType]] returnTypes: nil

if {$tcl_platform(platform) == "windows"} {
    set rootPath [[[[[@ $env(NEXT_ROOT)] pathComponents] objectAtIndex: 0] stringByAppendingPathComponent: [@ /]] retain]
} else {
    set rootPath [[@ /] retain]
}

$infoPanel center
$window center
$window makeKeyAndOrderFront: $self
